@@ -3,17 +3,17 @@ from __future__ import annotations
 import functools
 from typing import Any
 
-from glQiwiApi.core.abstracts import AbstractRouter
+from glQiwiApi.core.abc.router import AbstractRouter
 
 __all__ = ("YooMoneyRouter", "YooMoneyMethods")
 
 
 class YooMoneyRouter(AbstractRouter):
+    __head__ = "https://yoomoney.ru"
+
     def setup_routes(self) -> Any:
         return YooMoneyMethods()
 
-    __head__ = "https://yoomoney.ru"
-
     def setup_config(self) -> YooMoneyConfig:
         return YooMoneyConfig()
 
@@ -29,12 +29,12 @@ class YooMoneyConfig:
             "Host": "yoomoney.ru",
             "Content-Type": "application/x-www-form-urlencoded",
         }
-        self.ERROR_CODE_NUMBERS = {
-            400: "Ошибка, связанная с типом запроса к апи, "
-            "возможно вы передали недействительный API токен",
-            401: "Указан несуществующий, просроченный, или отозванный токен",
-            403: "Запрошена операция, на которую у токена нет прав",
-            0: "Ошибка, связанная с использованием прокси или непредвиденные ошибки сервера",
+        self.ERROR_CODE_MESSAGES = {
+            400: "An error related to the type of request to the api,"
+                 "you may have passed an invalid API token",
+            401: "A non-existent, expired, or revoked token is specified",
+            403: "An operation has been requested for which the token has no rights",
+            0: "Proxy error or unexpected server errors",
         }
         self.content_and_auth = {"content_json": True, "auth": True}
 
@@ -53,3 +53,6 @@ class YooMoneyMethods:
     PROCESS_PAYMENT: str = "/api/process-payment"
     ACCEPT_INCOMING_TRANSFER: str = "/api/incoming-transfer-accept"
     INCOMING_TRANSFER_REJECT: str = "/api/incoming-transfer-reject"
+
+    # Forms
+    QUICK_PAY_FORM: str = "/quickpay/confirm.xml?"
